diff --git a/components/desktop-environments.xml b/components/desktop-environments.xml
index 10ba178..994ea03 100644
--- a/components/desktop-environments.xml
+++ b/components/desktop-environments.xml
@@ -35,6 +35,7 @@
+
diff --git a/config.sh b/config.sh
index e26bf99..dd44ede 100755
--- a/config.sh
+++ b/config.sh
@@ -67,10 +67,15 @@ mkdir -p /var/log/journal
# Setup firstboot initial setup
#--------------------------------------
-## Enable initial-setup
-systemctl enable initial-setup.service
-## Enable reconfig mode
-touch /etc/reconfigSys
+if [[ "$kiwi_profiles" == *"KDE"* ]]; then
+ ## Enable calamares
+ systemctl enable calamares-firstboot.service
+else
+ ## Enable initial-setup
+ systemctl enable initial-setup.service
+ ## Enable reconfig mode
+ touch /etc/reconfigSys
+fi
#======================================
# Setup default target